@@ -317,60 +317,6 @@ void gcpBondTool::OnRelease ()
 	if (pItem)
 		pObject = dynamic_cast <Object *> (pItem->GetClient ());
 	m_pAtom = NULL;
-// FIXME: are these still needed? looks like the new canvas should do the job automagically.
-/*	if (pObject == NULL) {
-		std::map<Object const*, GnomeCanvasGroup*>::iterator i = m_pData->Items.begin (),
-					end = m_pData->Items.end ();
-		gcp::Bond* pBond;
-		while (i != end) {
-			if ((*i).first->GetType () == gcu::BondType) {
-				pBond = (gcp::Bond*) (*i).first;
-				if (pBond->GetDist(m_x1 / pDoc->GetTheme ()->GetZoomFactor (), m_y1 / pDoc->GetTheme ()->GetZoomFactor ()) < (pDoc->GetTheme ()->GetPadding () + pDoc->GetTheme ()->GetBondWidth () / 2) / pDoc->GetTheme ()->GetZoomFactor ()) {
-					pItem = GNOME_CANVAS_ITEM ((*i).second);
-					m_pObject = pBond;
-					break;
-				} else {
-					// may be one of the atoms might work
-					gcu::Atom *pAtom = pBond->GetAtom (0);
-					double xa, ya;
-					pAtom->GetCoords (&xa, &ya, NULL);
-					xa *= pDoc->GetTheme ()->GetZoomFactor ();
-					ya *= pDoc->GetTheme ()->GetZoomFactor ();
-					xa =- m_x1;
-					ya -= m_y1;
-					if (sqrt (xa * xa + ya * ya) < 3.5) {
-						//3.5 is arbitrary
-						m_pObject = pAtom;
-						break;
-					}
-					pAtom = pBond->GetAtom (1);
-					pAtom->GetCoords (&xa, &ya, NULL);
-					xa *= pDoc->GetTheme ()->GetZoomFactor ();
-					ya *= pDoc->GetTheme ()->GetZoomFactor ();
-					xa =- m_x1;
-					ya -= m_y1;
-					if (sqrt (xa * xa + ya * ya) < 3.5) {
-						pObject = pAtom;
-						break;
-					}
-				}
-			} else if ((*i).first->GetType () == gcu::AtomType) {
-				double xa, ya;
-				gcu::Atom *pAtom = (gcu::Atom*) (*i).first;
-				pAtom->GetCoords (&xa, &ya, NULL);
-				xa *= pDoc->GetTheme ()->GetZoomFactor ();
-				ya *= pDoc->GetTheme ()->GetZoomFactor ();
-				xa -= m_x1;
-				ya -= m_y1;
-				if (sqrt (xa * xa + ya * ya) < 3.5) {
-					//3.5 is arbitrary
-					pObject = pAtom;
-					break;
-				}
-			}
-			i++;
-		}
-	}*/
 	if (gcp::MergeAtoms && pObject) {
 		if (pObject->GetType () == BondType)
 			m_pAtom = (gcp::Atom*) pObject->GetAtomAt (m_x1 / m_dZoomFactor, m_y1 / m_dZoomFactor);
@@ -613,12 +559,25 @@ void gcpUpBondTool::SetType (gcp::Bond* pBond)//FIXME: Is it really useful?
 	pBond->SetType (gcp::UpBondType);
 }
 
+static void on_config_changed (GOConfNode *node, G_GNUC_UNUSED gchar const *key, gcp::Application *app)
+{
+	bool InvertWedgeHashes = go_conf_get_bool (node, "invert-wedge-hashes");
+	GtkWidget *w = app->GetToolItem("DownBond");
+	if (!w)
+		return;
+	gtk_tool_button_set_stock_id (GTK_TOOL_BUTTON (w), InvertWedgeHashes? "gcp_iDownBond": "gcp_DownBond");
+}
+
 gcpDownBondTool::gcpDownBondTool (gcp::Application *App): gcpBondTool (App, "DownBond", 4)
 {
+	m_ConfNode = go_conf_get_node (App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+	m_NotificationId = go_conf_add_monitor (m_ConfNode, NULL, (GOConfMonitorFunc) on_config_changed, GetApplication ());
 }
 
 gcpDownBondTool::~gcpDownBondTool ()
 {
+	go_conf_remove_monitor (m_NotificationId);
+	go_conf_free_node (m_ConfNode);
 }
 
 void gcpDownBondTool::Draw()
@@ -627,7 +586,9 @@ void gcpDownBondTool::Draw()
 	if (m_Item) {
 		static_cast <Hash *> (m_Item)->SetPosition (m_x1, m_y1, m_x0, m_y0);
 	} else {
-		gccv::Hash *hash = new Hash (m_pView->GetCanvas (), m_x1, m_y1, m_x0, m_y0, pTheme->GetStereoBondWidth ());
+		gccv::Hash *hash = gcp::InvertWedgeHashes?
+			new Hash (m_pView->GetCanvas (), m_x0, m_y0, m_x1, m_y1, pTheme->GetStereoBondWidth ()):
+			new Hash (m_pView->GetCanvas (), m_x1, m_y1, m_x0, m_y0, pTheme->GetStereoBondWidth ());
 		hash->SetFillColor (gcp::AddColor);
 		hash->SetLineWidth (pTheme->GetHashWidth ());
 		hash->SetLineDist (pTheme->GetHashDist ());
